==> docx4j-openxml-objects-pml-8.3.8-sources.jar: org/pptx4j/pml/STTLTimeNodeMasterRelation.java <==
/*
 *  Copyright 2010-2012, Plutext Pty Ltd.
 *   
 *  This file is part of pptx4j, a component of docx4j.

    docx4j is licensed under the Apache License, Version 2.0 (the "License"); 
    you may not use this file except in compliance with the License. 

    You may obtain a copy of the License at 

        http://www.apache.org/licenses/LICENSE-2.0 

    Unless required by applicable law or agreed to in writing, software 
    distributed under the License is distributed on an "AS IS" BASIS, 
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
    See the License for the specific language governing permissions and 
    limitations under the License.

 */
package org.pptx4j.pml;

import javax.xml.bind.annotation.XmlEnum;
import javax.xml.bind.annotation.XmlEnumValue;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for ST_TLTimeNodeMasterRelation.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * <p>
 * <pre>
 * &lt;simpleType name="ST_TLTimeNodeMasterRelation"&gt;
 *   &lt;restriction base="{http://www.w3.org/2001/XMLSchema}token"&gt;
 *     &lt;enumeration value="sameClick"/&gt;
 *     &lt;enumeration value="lastClick"/&gt;
 *     &lt;enumeration value="nextClick"/&gt;
 *   &lt;/restriction&gt;
 * &lt;/simpleType&gt;
 * </pre>
 * 
 */
@XmlType(name = "ST_TLTimeNodeMasterRelation")
@XmlEnum
public enum STTLTimeNodeMasterRelation {


    /**
     * TimeNode Master Relation Enum ( Same Click )
     * 
     */
    @XmlEnumValue("sameClick")
    SAME_CLICK("sameClick"),

    /**
     * TimeNode Master Relation Enum ( Last Click )
     * 
     */
    @XmlEnumValue("lastClick")
    LAST_CLICK("lastClick"),

    /**
     * TimeNode Master Relation Enum ( Next Click )
     * 
     */
    @XmlEnumValue("nextClick")
    NEXT_CLICK("nextClick");
    private final String value;

    STTLTimeNodeMasterRelation(String v) {
        value = v;
    }

    public String value() {
        return value;
    }

    public static STTLTimeNodeMasterRelation fromValue(String v) {
        for (STTLTimeNodeMasterRelation c: STTLTimeNodeMasterRelation.values()) {
            if (c.value.equals(v)) {
                return c;
            }
        }
        throw new IllegalArgumentException(v);
    }

}

==> docx4j-openxml-objects-pml-11.5.7-sources.jar: org/pptx4j/pml/STTLTimeNodeMasterRelation.java <==
/*
 *  Copyright 2010-2012, Plutext Pty Ltd.
 *   
 *  This file is part of pptx4j, a component of docx4j.

    docx4j is licensed under the Apache License, Version 2.0 (the "License"); 
    you may not use this file except in compliance with the License. 

    You may obtain a copy of the License at 

        http://www.apache.org/licenses/LICENSE-2.0 

    Unless required by applicable law or agreed to in writing, software 
    distributed under the License is distributed on an "AS IS" BASIS, 
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
    See the License for the specific language governing permissions and 
    limitations under the License.

 */
package org.pptx4j.pml;

import jakarta.xml.bind.annotation.XmlEnum;
import jakarta.xml.bind.annotation.XmlEnumValue;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <p>Java class for ST_TLTimeNodeMasterRelation.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * <p>
 * <pre>
 * &lt;simpleType name="ST_TLTimeNodeMasterRelation"&gt;
 *   &lt;restriction base="{http://www.w3.org/2001/XMLSchema}token"&gt;
 *     &lt;enumeration value="sameClick"/&gt;
 *     &lt;enumeration value="lastClick"/&gt;
 *     &lt;enumeration value="nextClick"/&gt;
 *   &lt;/restriction&gt;
 * &lt;/simpleType&gt;
 * </pre>
 * 
 */
@XmlType(name = "ST_TLTimeNodeMasterRelation")
@XmlEnum
public enum STTLTimeNodeMasterRelation {


    /**
     * TimeNode Master Relation Enum ( Same Click )
     * 
     */
    @XmlEnumValue("sameClick")
    SAME_CLICK("sameClick"),

    /**
     * TimeNode Master Relation Enum ( Last Click )
     * 
     */
    @XmlEnumValue("lastClick")
    LAST_CLICK("lastClick"),

    /**
     * TimeNode Master Relation Enum ( Next Click )
     * 
     */
    @XmlEnumValue("nextClick")
    NEXT_CLICK("nextClick");
    private final String value;

    STTLTimeNodeMasterRelation(String v) {
        value = v;
    }

    public String value() {
        return value;
    }

    public static STTLTimeNodeMasterRelation fromValue(String v) {
        for (STTLTimeNodeMasterRelation c: STTLTimeNodeMasterRelation.values()) {
            if (c.value.equals(v)) {
                return c;
            }
        }
        throw new IllegalArgumentException(v);
    }

}
